@@ -46,10 +46,7 @@ static struct {
 
 static GHashTable* foreign_structs_table = NULL;
 
-GJS_USE
-static GHashTable*
-get_foreign_structs(void)
-{
+[[nodiscard]] static GHashTable* get_foreign_structs() {
     // FIXME: look into hasing on GITypeInfo instead.
     if (!foreign_structs_table) {
         foreign_structs_table = g_hash_table_new_full(g_str_hash, g_str_equal,
@@ -60,11 +57,8 @@ get_foreign_structs(void)
     return foreign_structs_table;
 }
 
-GJS_USE
-static bool
-gjs_foreign_load_foreign_module(JSContext *context,
-                                const gchar *gi_namespace)
-{
+[[nodiscard]] static bool gjs_foreign_load_foreign_module(
+    JSContext* context, const char* gi_namespace) {
     int i;
 
     for (i = 0; foreign_modules[i].gi_namespace; ++i) {
@@ -106,11 +100,8 @@ void gjs_struct_foreign_register(const char* gi_namespace,
     g_hash_table_insert(get_foreign_structs(), canonical_name, info);
 }
 
-GJS_USE
-static GjsForeignInfo *
-gjs_struct_foreign_lookup(JSContext  *context,
-                          GIBaseInfo *interface_info)
-{
+[[nodiscard]] static GjsForeignInfo* gjs_struct_foreign_lookup(
+    JSContext* context, GIBaseInfo* interface_info) {
     GjsForeignInfo *retval = NULL;
     GHashTable *hash_table;
     char *key;
