@@ -36,9 +36,11 @@
 #include <js/TypeDecls.h>
 #include <js/Utility.h>  // for UniqueChars
 #include <js/Value.h>
+#include <js/ValueArray.h>
 #include <jsapi.h>    // for JS_DefinePropertyById, JS_GetProp...
 #include <jspubtd.h>  // for JSProtoKey, JSProto_Error, JSProt...
 
+#include "gi/arg-inl.h"
 #include "gi/boxed.h"
 #include "gi/enumeration.h"
 #include "gi/gerror.h"
@@ -255,10 +257,7 @@ bool ErrorPrototype::define_class(JSContext* context,
            gjs_define_enum_values(context, constructor, info);
 }
 
-GJS_USE
-static GIEnumInfo *
-find_error_domain_info(GQuark domain)
-{
+[[nodiscard]] static GIEnumInfo* find_error_domain_info(GQuark domain) {
     GIEnumInfo *info;
 
     /* first an attempt without loading extra libraries */
@@ -319,10 +318,7 @@ bool gjs_define_error_properties(JSContext* cx, JS::HandleObject obj) {
                                  JSPROP_ENUMERATE);
 }
 
-GJS_USE
-static JSProtoKey
-proto_key_from_error_enum(int val)
-{
+[[nodiscard]] static JSProtoKey proto_key_from_error_enum(int val) {
     switch (val) {
     case GJS_JS_ERROR_EVAL_ERROR:
         return JSProto_EvalError;
@@ -349,7 +345,7 @@ static JSObject *
 gjs_error_from_js_gerror(JSContext *cx,
                          GError    *gerror)
 {
-    JS::AutoValueArray<1> error_args(cx);
+    JS::RootedValueArray<1> error_args(cx);
     if (!gjs_string_from_utf8(cx, gerror->message, error_args[0]))
         return nullptr;
 
@@ -419,21 +415,21 @@ bool ErrorBase::transfer_to_gi_argument(JSContext* cx, JS::HandleObject obj,
              "transfer_to_gi_argument() must choose between in or out");
 
     if (!ErrorBase::typecheck(cx, obj)) {
-        arg->v_pointer = nullptr;
+        gjs_arg_unset<void*>(arg);
         return false;
     }
 
-    arg->v_pointer = ErrorBase::to_c_ptr(cx, obj);
-    if (!arg->v_pointer)
+    gjs_arg_set(arg, ErrorBase::to_c_ptr(cx, obj));
+    if (!gjs_arg_get<void*>(arg))
         return false;
 
     if ((transfer_direction == GI_DIRECTION_IN &&
          transfer_ownership != GI_TRANSFER_NOTHING) ||
         (transfer_direction == GI_DIRECTION_OUT &&
          transfer_ownership == GI_TRANSFER_EVERYTHING)) {
-        arg->v_pointer =
-            ErrorInstance::copy_ptr(cx, G_TYPE_ERROR, arg->v_pointer);
-        if (!arg->v_pointer)
+        gjs_arg_set(arg, ErrorInstance::copy_ptr(cx, G_TYPE_ERROR,
+                                                 gjs_arg_get<void*>(arg)));
+        if (!gjs_arg_get<void*>(arg))
             return false;
     }
 
