@@ -44,8 +44,7 @@
 
 static std::unordered_map<GType, AutoParamArray> class_init_properties;
 
-GJS_USE
-static JSContext* current_context(void) {
+[[nodiscard]] static JSContext* current_context() {
     GjsContext* gjs = gjs_context_get_current();
     return static_cast<JSContext*>(gjs_context_get_native_context(gjs));
 }
@@ -128,7 +127,7 @@ static GObject* gjs_object_constructor(
                                      construct_properties[i].pspec))
                 return nullptr;
 
-        JS::AutoValueArray<1> args(cx);
+        JS::RootedValueArray<1> args(cx);
         args[0].set(JS::ObjectValue(*props_hash));
         object = JS_New(cx, constructor, args);
     } else {
@@ -149,7 +148,7 @@ static GObject* gjs_object_constructor(
 }
 
 static void gjs_object_set_gproperty(GObject* object,
-                                     unsigned property_id G_GNUC_UNUSED,
+                                     unsigned property_id [[maybe_unused]],
                                      const GValue* value, GParamSpec* pspec) {
     auto* priv = ObjectInstance::for_gobject(object);
     JSContext *cx = current_context();
@@ -162,7 +161,7 @@ static void gjs_object_set_gproperty(GObject* object,
 }
 
 static void gjs_object_get_gproperty(GObject* object,
-                                     unsigned property_id G_GNUC_UNUSED,
+                                     unsigned property_id [[maybe_unused]],
                                      GValue* value, GParamSpec* pspec) {
     auto* priv = ObjectInstance::for_gobject(object);
     JSContext *cx = current_context();
@@ -201,7 +200,7 @@ static void gjs_object_class_init(void* class_pointer, void*) {
 }
 
 static void gjs_object_custom_init(GTypeInstance* instance,
-                                   void* g_class G_GNUC_UNUSED) {
+                                   void* g_class [[maybe_unused]]) {
     JSContext *cx = current_context();
     GjsContextPrivate* gjs = GjsContextPrivate::from_cx(cx);
 
