@@ -41,9 +41,7 @@ GJS_JSAPI_RETURN_CONVENTION
 bool gjs_gtype_get_actual_gtype(JSContext* context, JS::HandleObject object,
                                 GType* gtype_out);
 
-GJS_USE
-bool        gjs_typecheck_gtype         (JSContext             *context,
-                                         JS::HandleObject       obj,
-                                         bool                   throw_error);
+[[nodiscard]] bool gjs_typecheck_gtype(JSContext* cx, JS::HandleObject obj,
+                                       bool throw_error);
 
 #endif  // GI_GTYPE_H_
