@@ -120,7 +120,7 @@ ns_resolve(JSContext       *context,
 GJS_JSAPI_RETURN_CONVENTION
 static bool ns_new_enumerate(JSContext* cx, JS::HandleObject obj,
                              JS::MutableHandleIdVector properties,
-                             bool only_enumerable G_GNUC_UNUSED) {
+                             bool only_enumerable [[maybe_unused]]) {
     Ns* priv = priv_from_js(cx, obj);
 
     if (!priv) {
@@ -200,6 +200,7 @@ struct JSClass gjs_ns_class = {
 };
 
 static JSPropertySpec gjs_ns_proto_props[] = {
+    JS_STRING_SYM_PS(toStringTag, "GIRepositoryNamespace", JSPROP_READONLY),
     JS_PSG("__name__", get_name, GJS_MODULE_PROP_FLAGS),
     JS_PS_END
 };
