@@ -38,9 +38,11 @@
 #include <js/TypeDecls.h>
 #include <js/Utility.h>  // for UniqueChars
 #include <js/Value.h>
+#include <js/ValueArray.h>
 #include <jsapi.h>  // for InformalValueTypeName, JS_ClearPendingException
 #include <mozilla/Unused.h>
 
+#include "gi/arg-inl.h"
 #include "gi/arg.h"
 #include "gi/boxed.h"
 #include "gi/closure.h"
@@ -72,10 +74,8 @@ static bool gjs_value_from_g_value_internal(JSContext             *context,
  * only works for signals on introspected GObjects, not signals on GJS-defined
  * GObjects nor standalone closures. The return value must be unreffed.
  */
-GJS_USE
-static GISignalInfo *
-get_signal_info_if_available(GSignalQuery *signal_query)
-{
+[[nodiscard]] static GISignalInfo* get_signal_info_if_available(
+    GSignalQuery* signal_query) {
     GIBaseInfo *obj;
     GIInfoType info_type;
     GISignalInfo *signal_info = NULL;
@@ -125,7 +125,7 @@ gjs_value_from_array_and_length_values(JSContext             *context,
                                          signal_query, array_length_arg_n))
         return false;
 
-    array_arg.v_pointer = g_value_get_pointer(array_value);
+    gjs_arg_set(&array_arg, g_value_get_pointer(array_value));
 
     return gjs_value_from_explicit_array(context, value_p, array_type_info,
                                          &array_arg, array_length.toInt32());
@@ -584,7 +584,7 @@ gjs_value_to_g_value_internal(JSContext      *context,
                                                                        true, &arg))
                             return false;
 
-                        gboxed = arg.v_pointer;
+                        gboxed = gjs_arg_get<void*>(&arg);
                     }
                 }
 
@@ -760,11 +760,7 @@ gjs_value_to_g_value_no_copy(JSContext      *context,
     return gjs_value_to_g_value_internal(context, value, gvalue, true);
 }
 
-GJS_USE
-static JS::Value
-convert_int_to_enum (GType  gtype,
-                     int    v)
-{
+[[nodiscard]] static JS::Value convert_int_to_enum(GType gtype, int v) {
     double v_double;
 
     if (v > 0 && v < G_MAXINT) {
@@ -910,7 +906,7 @@ gjs_value_from_g_value_internal(JSContext             *context,
         if (info.type() == GI_INFO_TYPE_STRUCT &&
             g_struct_info_is_foreign(info)) {
             GIArgument arg;
-            arg.v_pointer = gboxed;
+            gjs_arg_set(&arg, gboxed);
             return gjs_struct_foreign_convert_from_g_argument(context, value_p,
                                                               info, &arg);
         }
@@ -961,7 +957,7 @@ gjs_value_from_g_value_internal(JSContext             *context,
                   " calling gjs_value_from_g_value_internal()",
                   g_type_info_get_array_length(&type_info) == -1));
 
-        arg.v_pointer = g_value_get_pointer(gvalue);
+        gjs_arg_set(&arg, g_value_get_pointer(gvalue));
 
         res = gjs_value_from_g_argument(context, value_p, &type_info, &arg, true);
 
