@@ -45,10 +45,7 @@ GJS_JSAPI_RETURN_CONVENTION
 JSObject *    gjs_byte_array_from_byte_array (JSContext  *context,
                                               GByteArray *array);
 
-GJS_USE
-GByteArray* gjs_byte_array_get_byte_array(JSObject* obj);
-
-GJS_USE
-GBytes* gjs_byte_array_get_bytes(JSObject* obj);
+[[nodiscard]] GByteArray* gjs_byte_array_get_byte_array(JSObject* obj);
+[[nodiscard]] GBytes* gjs_byte_array_get_bytes(JSObject* obj);
 
 #endif  // GJS_BYTEARRAY_H_
