@@ -24,6 +24,7 @@
 #include <config.h>
 
 #include <signal.h>  // for sigaction, SIGUSR1, sa_handler
+#include <stdint.h>
 #include <stdio.h>      // for FILE, fclose, size_t
 #include <string.h>     // for memset
 
@@ -34,7 +35,8 @@
 #endif
 
 #include <new>
-#include <string>  // for u16string
+#include <string>       // for u16string
+#include <type_traits>  // for remove_reference<>::type
 #include <unordered_map>
 #include <utility>  // for move
 #include <vector>
@@ -65,10 +67,10 @@
 #include <js/UniquePtr.h>
 #include <js/Utility.h>  // for DeletePolicy
 #include <js/Value.h>
+#include <js/ValueArray.h>
 #include <jsapi.h>        // for JS_IsExceptionPending, ...
 #include <jsfriendapi.h>  // for DumpHeap, IgnoreNurseryObjects
 #include <mozilla/UniquePtr.h>
-#include <mozilla/Vector.h>
 
 #include "gi/object.h"
 #include "gi/private.h"
@@ -118,15 +120,7 @@ struct _GjsContextClass {
     GObjectClass parent;
 };
 
-/* Temporary workaround for https://bugzilla.gnome.org/show_bug.cgi?id=793175 */
-#if __GNUC__ >= 8
-_Pragma("GCC diagnostic push")
-_Pragma("GCC diagnostic ignored \"-Wcast-function-type\"")
-#endif
 G_DEFINE_TYPE_WITH_PRIVATE(GjsContext, gjs_context, G_TYPE_OBJECT);
-#if __GNUC__ >= 8
-_Pragma("GCC diagnostic pop")
-#endif
 
 GjsContextPrivate* GjsContextPrivate::from_object(GObject* js_context) {
     g_return_val_if_fail(GJS_IS_CONTEXT(js_context), nullptr);
@@ -192,7 +186,7 @@ static gboolean dump_heap_idle(void*) {
     return false;
 }
 
-static void dump_heap_signal_handler(int signum G_GNUC_UNUSED) {
+static void dump_heap_signal_handler(int signum [[maybe_unused]]) {
     if (dump_heap_idle_id == 0)
         dump_heap_idle_id = g_idle_add_full(G_PRIORITY_HIGH_IDLE,
                                             dump_heap_idle, nullptr, nullptr);
@@ -494,7 +488,9 @@ GjsContextPrivate::GjsContextPrivate(JSContext* cx, GjsContext* public_context)
 
     m_atoms = new GjsAtoms();
 
-    JS::RootedObject global(m_cx, gjs_create_global_object(m_cx));
+    JS::RootedObject global(
+        m_cx, gjs_create_global_object(cx, GjsGlobalType::DEFAULT));
+
     if (!global) {
         gjs_log_exception(m_cx);
         g_error("Failed to initialize global object");
@@ -519,14 +515,15 @@ GjsContextPrivate::GjsContextPrivate(JSContext* cx, GjsContext* public_context)
         g_error("Failed to create root importer");
     }
 
-    JS::Value v_importer = gjs_get_global_slot(m_cx, GJS_GLOBAL_SLOT_IMPORTS);
+    JS::Value v_importer = gjs_get_global_slot(global, GjsGlobalSlot::IMPORTS);
     g_assert(((void) "Someone else already created root importer",
               v_importer.isUndefined()));
 
-    gjs_set_global_slot(m_cx, GJS_GLOBAL_SLOT_IMPORTS,
+    gjs_set_global_slot(global, GjsGlobalSlot::IMPORTS,
                         JS::ObjectValue(*importer));
 
-    if (!gjs_define_global_properties(m_cx, global, "GJS", "default")) {
+    if (!gjs_define_global_properties(m_cx, global, GjsGlobalType::DEFAULT,
+                                      "GJS", "default")) {
         gjs_log_exception(m_cx);
         g_error("Failed to define properties on global object");
     }
@@ -698,9 +695,9 @@ JSObject* GjsContextPrivate::getIncumbentGlobal(JSContext* cx) {
 
 /* See engine.cpp and JS::SetEnqueuePromiseJobCallback(). */
 bool GjsContextPrivate::enqueuePromiseJob(
-    JSContext* cx, JS::HandleObject promise G_GNUC_UNUSED, JS::HandleObject job,
-    JS::HandleObject allocation_site G_GNUC_UNUSED,
-    JS::HandleObject incumbent_global G_GNUC_UNUSED) {
+    JSContext* cx, JS::HandleObject promise [[maybe_unused]],
+    JS::HandleObject job, JS::HandleObject allocation_site [[maybe_unused]],
+    JS::HandleObject incumbent_global [[maybe_unused]]) {
     g_assert(cx == m_cx);
     g_assert(from_cx(cx) == this);
 
