@@ -135,7 +135,8 @@ void gjs_context_setup_debugger_console(GjsContext* gjs) {
     auto cx = static_cast<JSContext*>(gjs_context_get_native_context(gjs));
 
     JS::RootedObject debuggee(cx, gjs_get_import_global(cx));
-    JS::RootedObject debugger_global(cx, gjs_create_global_object(cx));
+    JS::RootedObject debugger_global(
+        cx, gjs_create_global_object(cx, GjsGlobalType::DEBUGGER));
 
     // Enter realm of the debugger and initialize it with the debuggee
     JSAutoRealm ar(cx, debugger_global);
@@ -149,7 +150,8 @@ void gjs_context_setup_debugger_console(GjsContext* gjs) {
     JS::RootedValue v_wrapper(cx, JS::ObjectValue(*debuggee_wrapper));
     if (!JS_SetPropertyById(cx, debugger_global, atoms.debuggee(), v_wrapper) ||
         !JS_DefineFunctions(cx, debugger_global, debugger_funcs) ||
-        !gjs_define_global_properties(cx, debugger_global, "GJS debugger",
+        !gjs_define_global_properties(cx, debugger_global,
+                                      GjsGlobalType::DEBUGGER, "GJS debugger",
                                       "debugger"))
         gjs_log_exception(cx);
 }
