@@ -38,6 +38,7 @@
 #include <utility>  // for move
 #include <vector>
 
+#include <js/Array.h>
 #include <js/CallArgs.h>
 #include <js/CharacterEncoding.h>
 #include <js/Class.h>
@@ -48,6 +49,7 @@
 #include <js/RootingAPI.h>
 #include <js/TypeDecls.h>
 #include <js/Value.h>
+#include <js/ValueArray.h>
 #include <jsapi.h>        // for JS_GetPropertyById, JS_ClearPendin...
 #include <jsfriendapi.h>  // for ProtoKeyToClass
 
@@ -236,7 +238,7 @@ JSObject* gjs_build_string_array(JSContext* context,
         elems.infallibleAppend(element);
     }
 
-    return JS_NewArrayObject(context, elems);
+    return JS::NewArrayObject(context, elems);
 }
 
 JSObject* gjs_define_string_array(JSContext* context,
@@ -263,11 +265,8 @@ JSObject* gjs_define_string_array(JSContext* context,
  * are \x escaped.
  *
  */
-GJS_USE
-static char *
-gjs_string_readable(JSContext       *context,
-                    JS::HandleString string)
-{
+[[nodiscard]] static char* gjs_string_readable(JSContext* context,
+                                               JS::HandleString string) {
     GString *buf = g_string_new("");
 
     g_string_append_c(buf, '"');
@@ -295,10 +294,7 @@ gjs_string_readable(JSContext       *context,
     return g_string_free(buf, false);
 }
 
-GJS_USE
-static char *
-_gjs_g_utf8_make_valid (const char *name)
-{
+[[nodiscard]] static char* _gjs_g_utf8_make_valid(const char* name) {
     GString *string;
     const char *remainder, *invalid;
     int remaining_bytes, valid_bytes;
@@ -407,12 +403,11 @@ bool gjs_log_exception_full(JSContext* context, JS::HandleValue exc,
     bool is_syntax = false, is_internal = false;
     if (exc.isObject()) {
         exc_obj = &exc.toObject();
-        const JSClass* syntax_error =
-            js::Jsvalify(js::ProtoKeyToClass(JSProto_SyntaxError));
+        const JSClass* syntax_error = js::ProtoKeyToClass(JSProto_SyntaxError);
         is_syntax = JS_InstanceOf(context, exc_obj, syntax_error, nullptr);
 
         const JSClass* internal_error =
-            js::Jsvalify(js::ProtoKeyToClass(JSProto_InternalError));
+            js::ProtoKeyToClass(JSProto_InternalError);
         is_internal = JS_InstanceOf(context, exc_obj, internal_error, nullptr);
     }
 
