@@ -20,12 +20,11 @@
  * IN THE SOFTWARE.
  */
 
-#include <config.h> /* IWYU pragma: keep */
+#include <config.h>
 
 #include <locale.h>    /* for setlocale */
 #include <stddef.h>    /* for size_t */
 #include <string.h>    /* for strcmp */
-#include <sys/types.h> /* IWYU pragma: keep */
 
 #include <gio/gio.h>
 #include <glib-object.h>
