@@ -29,12 +29,14 @@
 
 #include <js/CallArgs.h>
 #include <js/Class.h>
+#include <js/PropertyDescriptor.h>  // for JSPROP_READONLY
 #include <js/PropertySpec.h>
 #include <js/RootingAPI.h>
 #include <js/TypeDecls.h>
 #include <js/Value.h>
 #include <jsapi.h>  // for JS_GetPrivate, JS_GetClass, ...
 
+#include "gi/arg-inl.h"
 #include "gi/arg.h"
 #include "gi/foreign.h"
 #include "gjs/jsapi-class.h"
@@ -55,9 +57,11 @@ static void gjs_cairo_surface_finalize(JSFreeOp*, JSObject* obj) {
 }
 
 /* Properties */
+// clang-format off
 JSPropertySpec gjs_cairo_surface_proto_props[] = {
-    JS_PS_END
-};
+    JS_STRING_SYM_PS(toStringTag, "Surface", JSPROP_READONLY),
+    JS_PS_END};
+// clang-format on
 
 /* Methods */
 GJS_JSAPI_RETURN_CONVENTION
@@ -236,16 +240,10 @@ cairo_surface_t* gjs_cairo_surface_get_surface(
     return static_cast<cairo_surface_t*>(JS_GetPrivate(surface_wrapper));
 }
 
-GJS_USE
-static bool
-surface_to_g_argument(JSContext      *context,
-                      JS::Value       value,
-                      const char     *arg_name,
-                      GjsArgumentType argument_type,
-                      GITransfer      transfer,
-                      bool            may_be_null,
-                      GArgument      *arg)
-{
+[[nodiscard]] static bool surface_to_g_argument(
+    JSContext* context, JS::Value value, const char* arg_name,
+    GjsArgumentType argument_type, GITransfer transfer, bool may_be_null,
+    GIArgument* arg) {
     if (value.isNull()) {
         if (!may_be_null) {
             GjsAutoChar display_name =
@@ -254,7 +252,7 @@ surface_to_g_argument(JSContext      *context,
             return false;
         }
 
-        arg->v_pointer = nullptr;
+        gjs_arg_unset<void*>(arg);
         return true;
     }
 
@@ -273,7 +271,7 @@ surface_to_g_argument(JSContext      *context,
     if (transfer == GI_TRANSFER_EVERYTHING)
         cairo_surface_destroy(s);
 
-    arg->v_pointer = s;
+    gjs_arg_set(arg, s);
     return true;
 }
 
@@ -283,9 +281,8 @@ surface_from_g_argument(JSContext             *context,
                         JS::MutableHandleValue value_p,
                         GIArgument            *arg)
 {
-    JSObject *obj;
-
-    obj = gjs_cairo_surface_from_surface(context, (cairo_surface_t*)arg->v_pointer);
+    JSObject* obj = gjs_cairo_surface_from_surface(
+        context, gjs_arg_get<cairo_surface_t*>(arg));
     if (!obj)
         return false;
 
@@ -296,7 +293,7 @@ surface_from_g_argument(JSContext             *context,
 static bool surface_release_argument(JSContext*, GITransfer transfer,
                                      GIArgument* arg) {
     if (transfer != GI_TRANSFER_NOTHING)
-        cairo_surface_destroy(static_cast<cairo_surface_t*>(arg->v_pointer));
+        cairo_surface_destroy(gjs_arg_get<cairo_surface_t*>(arg));
     return true;
 }
 
