@@ -421,6 +421,8 @@ function* _listModelIterator() {
 }
 
 function _promisify(proto, asyncFunc, finishFunc) {
+    if (proto[`_original_${asyncFunc}`] !== undefined)
+        return;
     proto[`_original_${asyncFunc}`] = proto[asyncFunc];
     proto[asyncFunc] = function (...args) {
         if (!args.every(arg => typeof arg !== 'function'))
@@ -429,7 +431,9 @@ function _promisify(proto, asyncFunc, finishFunc) {
             const callStack = new Error().stack.split('\n').filter(line => !line.match(/promisify/)).join('\n');
             this[`_original_${asyncFunc}`](...args, function (source, res) {
                 try {
-                    const result = source[finishFunc](res);
+                    const result = source !== null && source[finishFunc] !== undefined
+                        ? source[finishFunc](res)
+                        : proto[finishFunc](res);
                     if (Array.isArray(result) && result.length > 1 && result[0] === true)
                         result.shift();
                     resolve(result);
