@@ -21,17 +21,9 @@
  * IN THE SOFTWARE.
  */
 
-#ifndef __GJS_MODULES_H__
-#define __GJS_MODULES_H__
-
-#include <config.h>
-#include <glib.h>
-#include "gjs/jsapi-util.h"
-
-G_BEGIN_DECLS
+#ifndef MODULES_MODULES_H_
+#define MODULES_MODULES_H_
 
 void gjs_register_static_modules (void);
 
-G_END_DECLS
-
-#endif  /* __GJS_CONSOLE_H__ */
+#endif  // MODULES_MODULES_H_
